@@ -2,11 +2,11 @@
 ===============================================================================
 
   FILE:  lasquadtree.cpp
-
+  
   CONTENTS:
-
+  
     see corresponding header file
-
+  
   PROGRAMMERS:
 
     martin.isenburg@rapidlasso.com  -  http://rapidlasso.com
@@ -21,14 +21,13 @@
 
     This software is distributed WITHOUT ANY WARRANTY and without even the
     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
+  
   CHANGE HISTORY:
-
+  
     see corresponding header file
-
+  
 ===============================================================================
 */
-
 #include "lasquadtree.hpp"
 
 #include "bytestreamin.hpp"
@@ -109,7 +108,7 @@ void LASquadtree::get_cell_bounding_box(const F64 x, const F64 y, U32 level, F32
   volatile float cell_mid_y;
   float cell_min_x, cell_max_x;
   float cell_min_y, cell_max_y;
-
+  
   cell_min_x = min_x;
   cell_max_x = max_x;
   cell_min_y = min_y;
@@ -162,7 +161,7 @@ void LASquadtree::get_cell_bounding_box(U32 level_index, U32 level, F32* min, F3
   volatile F32 cell_mid_y;
   F32 cell_min_x, cell_max_x;
   F32 cell_min_y, cell_max_y;
-
+  
   cell_min_x = min_x;
   cell_max_x = max_x;
   cell_min_y = min_y;
@@ -211,7 +210,7 @@ void LASquadtree::get_cell_bounding_box(U32 level_index, U32 level, F64* min, F6
   volatile F64 cell_mid_y;
   F64 cell_min_x, cell_max_x;
   F64 cell_min_y, cell_max_y;
-
+  
   cell_min_x = min_x;
   cell_max_x = max_x;
   cell_min_y = min_y;
@@ -280,7 +279,7 @@ U32 LASquadtree::get_level_index(const F64 x, const F64 y, U32 level) const
   volatile float cell_mid_y;
   float cell_min_x, cell_max_x;
   float cell_min_y, cell_max_y;
-
+  
   cell_min_x = min_x;
   cell_max_x = max_x;
   cell_min_y = min_y;
@@ -332,7 +331,7 @@ U32 LASquadtree::get_level_index(const F64 x, const F64 y, U32 level, F32* min,
   volatile float cell_mid_y;
   float cell_min_x, cell_max_x;
   float cell_min_y, cell_max_y;
-
+  
   cell_min_x = min_x;
   cell_max_x = max_x;
   cell_min_y = min_y;
@@ -406,7 +405,7 @@ U32 LASquadtree::get_cell_index(const F64 x, const F64 y) const
 }
 
 // returns the indices of parent and siblings for the specified cell index
-BOOL LASquadtree::coarsen(const I32 cell_index, I32* coarser_cell_index, U32* num_cell_indices, I32** cell_indices) const
+BOOL LASquadtree::coarsen(const I32 cell_index, I32* coarser_cell_index, U32* num_cell_indices, I32** cell_indices)
 {
   if (cell_index < 0) return FALSE;
   U32 level = get_level((U32)cell_index);
@@ -578,13 +577,13 @@ U32* LASquadtree::raster_occupancy(BOOL(*does_cell_exist)(I32)) const
 BOOL LASquadtree::read(ByteStreamIn* stream)
 {
   // read data in the following order
-  //     U32  levels          4 bytes
+  //     U32  levels          4 bytes 
   //     U32  level_index     4 bytes (default 0)
   //     U32  implicit_levels 4 bytes (only used when level_index != 0))
-  //     F32  min_x           4 bytes
-  //     F32  max_x           4 bytes
-  //     F32  min_y           4 bytes
-  //     F32  max_y           4 bytes
+  //     F32  min_x           4 bytes 
+  //     F32  max_x           4 bytes 
+  //     F32  min_y           4 bytes 
+  //     F32  max_y           4 bytes 
   // which totals 28 bytes
 
   char signature[4];
@@ -672,16 +671,16 @@ BOOL LASquadtree::read(ByteStreamIn* stream)
 BOOL LASquadtree::write(ByteStreamOut* stream) const
 {
   // which totals 28 bytes
-  //     U32  levels          4 bytes
+  //     U32  levels          4 bytes 
   //     U32  level_index     4 bytes (default 0)
   //     U32  implicit_levels 4 bytes (only used when level_index != 0))
-  //     F32  min_x           4 bytes
-  //     F32  max_x           4 bytes
-  //     F32  min_y           4 bytes
-  //     F32  max_y           4 bytes
+  //     F32  min_x           4 bytes 
+  //     F32  max_x           4 bytes 
+  //     F32  min_y           4 bytes 
+  //     F32  max_y           4 bytes 
   // which totals 28 bytes
 
-  if (!stream->putBytes((U8*)"LASS", 4))
+  if (!stream->putBytes((const U8*)"LASS", 4))
   {
     REprintf("ERROR (LASquadtree): writing LASspatial signature\n");
     return FALSE;
@@ -694,52 +693,52 @@ BOOL LASquadtree::write(ByteStreamOut* stream) const
     return FALSE;
   }
 
-  if (!stream->putBytes((U8*)"LASQ", 4))
+  if (!stream->putBytes((const U8*)"LASQ", 4))
   {
     REprintf("ERROR (LASquadtree): writing signature\n");
     return FALSE;
   }
 
   U32 version = 0;
-  if (!stream->put32bitsLE((U8*)&version))
+  if (!stream->put32bitsLE((const U8*)&version))
   {
     REprintf("ERROR (LASquadtree): writing version\n");
     return FALSE;
   }
 
-  if (!stream->put32bitsLE((U8*)&levels))
+  if (!stream->put32bitsLE((const U8*)&levels))
   {
     REprintf("ERROR (LASquadtree): writing levels %u\n", levels);
     return FALSE;
   }
   U32 level_index = 0;
-  if (!stream->put32bitsLE((U8*)&level_index))
+  if (!stream->put32bitsLE((const U8*)&level_index))
   {
     REprintf("ERROR (LASquadtree): writing level_index %u\n", level_index);
     return FALSE;
   }
   U32 implicit_levels = 0;
-  if (!stream->put32bitsLE((U8*)&implicit_levels))
+  if (!stream->put32bitsLE((const U8*)&implicit_levels))
   {
     REprintf("ERROR (LASquadtree): writing implicit_levels %u\n", implicit_levels);
     return FALSE;
   }
-  if (!stream->put32bitsLE((U8*)&min_x))
+  if (!stream->put32bitsLE((const U8*)&min_x))
   {
     REprintf("ERROR (LASquadtree): writing min_x %g\n", min_x);
     return FALSE;
   }
-  if (!stream->put32bitsLE((U8*)&max_x))
+  if (!stream->put32bitsLE((const U8*)&max_x))
   {
     REprintf("ERROR (LASquadtree): writing max_x %g\n", max_x);
     return FALSE;
   }
-  if (!stream->put32bitsLE((U8*)&min_y))
+  if (!stream->put32bitsLE((const U8*)&min_y))
   {
     REprintf("ERROR (LASquadtree): writing min_y %g\n", min_y);
     return FALSE;
   }
-  if (!stream->put32bitsLE((U8*)&max_y))
+  if (!stream->put32bitsLE((const U8*)&max_y))
   {
     REprintf("ERROR (LASquadtree): writing max_y %g\n", max_y);
     return FALSE;
@@ -747,7 +746,7 @@ BOOL LASquadtree::write(ByteStreamOut* stream) const
   return TRUE;
 }
 
-// create or finalize the cell (in the spatial hierarchy)
+// create or finalize the cell (in the spatial hierarchy) 
 BOOL LASquadtree::manage_cell(const U32 cell_index, const BOOL finalize)
 {
   U32 adaptive_pos = cell_index/32;
@@ -870,8 +869,8 @@ U32 LASquadtree::intersect_circle(const F64 center_x, const F64 center_y, const
     ((my_cell_vector*)current_cells)->clear();
   }
 
-  F64 r_min_x = center_x - radius;
-  F64 r_min_y = center_y - radius;
+  F64 r_min_x = center_x - radius; 
+  F64 r_min_y = center_y - radius; 
   F64 r_max_x = center_x + radius;
   F64 r_max_y = center_y + radius;
 
